[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --fast-version-control
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NOMBRE](https://git-scm.com/docs/git/es#_nombre)
    * [SINOPSIS](https://git-scm.com/docs/git/es#_sinopsis)
    * [DESCRIPCIÓN](https://git-scm.com/docs/git/es#_descripci%c3%b3n)
    * [OPCIONES](https://git-scm.com/docs/git/es#_opciones)
    * [COMANDOS GIT](https://git-scm.com/docs/git/es#_comandos_git)
    * [Comandos de alto nivel (porcelana)](https://git-scm.com/docs/git/es#_comandos_de_alto_nivel_porcelana)
    * [Comandos de bajo nivel (plomería)](https://git-scm.com/docs/git/es#_comandos_de_bajo_nivel_plomer%c3%ada)
    * [Guías](https://git-scm.com/docs/git/es#_gu%c3%adas)
    * [Interfases de repositorio, comando y fichero](https://git-scm.com/docs/git/es#_interfases_de_repositorio_comando_y_fichero)
    * [Formatos de fichero, protocolos y otras interfaces para el desarrollador](https://git-scm.com/docs/git/es#_formatos_de_fichero_protocolos_y_otras_interfaces_para_el_desarrollador)
    * [Mecanismo de Configuración](https://git-scm.com/docs/git/es#_mecanismo_de_configuraci%c3%b3n)
    * [Terminología Identificadora](https://git-scm.com/docs/git/es#_terminolog%c3%ada_identificadora)
    * [Identificadores Simbólicos](https://git-scm.com/docs/git/es#_identificadores_simb%c3%b3licos)
    * [Estructura de Ficheros/Directorios](https://git-scm.com/docs/git/es#_estructura_de_ficherosdirectorios)
    * [Terminología](https://git-scm.com/docs/git/es#_terminolog%c3%ada)
    * [Variables de Ambiente](https://git-scm.com/docs/git/es#_variables_de_ambiente)
    * [Discusión](https://git-scm.com/docs/git/es#_discusi%c3%b3n)
    * [SEGURIDAD](https://git-scm.com/docs/git/es#_seguridad)
    * [MAS DOCUMENTACIÓN](https://git-scm.com/docs/git/es#_mas_documentaci%c3%b3n)
    * [Autores](https://git-scm.com/docs/git/es#_autores)
    * [Reportando Errores](https://git-scm.com/docs/git/es#_reportando_errores)
    * [VER TAMBIÉN](https://git-scm.com/docs/git/es#_ver_tambi%c3%a9n)
    * [GIT](https://git-scm.com/docs/git/es#_git)


[ Español ▾](https://git-scm.com/docs/git/es)
Localized versions of **git** manual
  1. [English ](https://git-scm.com/docs/git)
  2. [Deutsch ](https://git-scm.com/docs/git/de)
  3. [Español ](https://git-scm.com/docs/git/es)
  4. [Français ](https://git-scm.com/docs/git/fr)
  5. [Português (Brasil) ](https://git-scm.com/docs/git/pt_BR)
  6. [Svenska ](https://git-scm.com/docs/git/sv)
  7. [українська мова ](https://git-scm.com/docs/git/uk)
  8. [简体中文 ](https://git-scm.com/docs/git/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git/es)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git/es)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init/es)
  * [ clone ](https://git-scm.com/docs/git-clone/es)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add/es)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff/es)
  * [ commit ](https://git-scm.com/docs/git-commit/es)
  * [ notes ](https://git-scm.com/docs/git-notes/es)
  * [ restore ](https://git-scm.com/docs/git-restore/es)
  * [ reset ](https://git-scm.com/docs/git-reset/es)
  * [ rm ](https://git-scm.com/docs/git-rm/es)
  * [ mv ](https://git-scm.com/docs/git-mv/es)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff/es)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff/es)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary/es)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree/es)


[ Latest version ▾ ](https://git-scm.com/docs/git/es) git last updated in 2.53.0
Changes in the **git** manual
  1. [2.53.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2026-02-02_ ](https://git-scm.com/docs/git/2.53.0)
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/git/2.52.0)
  3. 2.51.2 no changes
  4. [2.51.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-10-15_ ](https://git-scm.com/docs/git/2.51.1)
  5. 2.50.1 → 2.51.0 no changes
  6. [2.50.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-06-16_ ](https://git-scm.com/docs/git/2.50.0)
  7. 2.49.1 no changes
  8. [2.49.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-03-14_ ](https://git-scm.com/docs/git/2.49.0)
  9. 2.48.1 → 2.48.2 no changes
  10. [2.48.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-01-10_ ](https://git-scm.com/docs/git/2.48.0)
  11. 2.47.1 → 2.47.3 no changes
  12. [2.47.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-10-06_ ](https://git-scm.com/docs/git/2.47.0)
  13. 2.46.1 → 2.46.4 no changes
  14. [2.46.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-07-29_ ](https://git-scm.com/docs/git/2.46.0)
  15. 2.45.2 → 2.45.4 no changes
  16. [2.45.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.1)
  17. [2.45.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.0)
  18. 2.44.2 → 2.44.4 no changes
  19. [2.44.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.44.1)
  20. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git/2.44.0)
  21. 2.43.5 → 2.43.7 no changes
  22. [2.43.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.43.4)
  23. 2.43.2 → 2.43.3 no changes
  24. [2.43.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-09_ ](https://git-scm.com/docs/git/2.43.1)
  25. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/git/2.43.0)
  26. 2.42.3 → 2.42.4 no changes
  27. [2.42.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.42.2)
  28. [2.42.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-02_ ](https://git-scm.com/docs/git/2.42.1)
  29. [2.42.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-08-21_ ](https://git-scm.com/docs/git/2.42.0)
  30. 2.41.2 → 2.41.3 no changes
  31. [2.41.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.41.1)
  32. [2.41.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-06-01_ ](https://git-scm.com/docs/git/2.41.0)
  33. 2.40.3 → 2.40.4 no changes
  34. [2.40.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.40.2)
  35. 2.40.1 no changes
  36. 2.40.0 no changes
  37. 2.39.5 no changes
  38. [2.39.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.39.4)
  39. 2.39.1 → 2.39.3 no changes
  40. [2.39.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-12_ ](https://git-scm.com/docs/git/2.39.0)
  41. 2.38.3 → 2.38.5 no changes
  42. [2.38.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-11_ ](https://git-scm.com/docs/git/2.38.2)
  43. 2.38.1 no changes
  44. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/git/2.38.0)
  45. 2.37.3 → 2.37.7 no changes
  46. [2.37.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-08-11_ ](https://git-scm.com/docs/git/2.37.2)
  47. 2.37.1 no changes
  48. [2.37.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-06-27_ ](https://git-scm.com/docs/git/2.37.0)
  49. 2.36.1 → 2.36.6 no changes
  50. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git/2.36.0)
  51. 2.35.1 → 2.35.8 no changes
  52. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git/2.35.0)
  53. 2.34.1 → 2.34.8 no changes
  54. [2.34.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-11-15_ ](https://git-scm.com/docs/git/2.34.0)
  55. 2.33.3 → 2.33.8 no changes
  56. [2.33.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-03-23_ ](https://git-scm.com/docs/git/2.33.2)
  57. [2.33.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-10-12_ ](https://git-scm.com/docs/git/2.33.1)
  58. 2.32.1 → 2.33.0 no changes
  59. [2.32.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-06-06_ ](https://git-scm.com/docs/git/2.32.0)
  60. 2.31.1 → 2.31.8 no changes
  61. [2.31.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-03-15_ ](https://git-scm.com/docs/git/2.31.0)
  62. 2.30.1 → 2.30.9 no changes
  63. [2.30.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-12-27_ ](https://git-scm.com/docs/git/2.30.0)
  64. 2.29.1 → 2.29.3 no changes
  65. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git/2.29.0)
  66. 2.28.1 no changes
  67. [2.28.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-07-27_ ](https://git-scm.com/docs/git/2.28.0)
  68. 2.27.1 no changes
  69. [2.27.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-06-01_ ](https://git-scm.com/docs/git/2.27.0)
  70. 2.26.1 → 2.26.3 no changes
  71. [2.26.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-03-22_ ](https://git-scm.com/docs/git/2.26.0)
  72. 2.25.2 → 2.25.5 no changes
  73. [2.25.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-02-17_ ](https://git-scm.com/docs/git/2.25.1)
  74. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/git/2.25.0)
  75. 2.23.1 → 2.24.4 no changes
  76. [2.23.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-16_ ](https://git-scm.com/docs/git/2.23.0)
  77. 2.22.2 → 2.22.5 no changes
  78. [2.22.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-11_ ](https://git-scm.com/docs/git/2.22.1)
  79. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git/2.22.0)
  80. 2.20.1 → 2.21.4 no changes
  81. [2.20.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-12-09_ ](https://git-scm.com/docs/git/2.20.0)
  82. 2.19.3 → 2.19.6 no changes
  83. [2.19.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-11-21_ ](https://git-scm.com/docs/git/2.19.2)
  84. 2.19.1 no changes
  85. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git/2.19.0)
  86. 2.18.1 → 2.18.5 no changes
  87. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git/2.18.0)
  88. 2.17.1 → 2.17.6 no changes
  89. [2.17.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-04-02_ ](https://git-scm.com/docs/git/2.17.0)
  90. [2.16.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.16.6)
  91. [2.15.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.15.4)
  92. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.14.6)
  93. 2.13.7 no changes
  94. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.12.5)
  95. [2.11.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.11.4)
  96. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.10.5)
  97. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.9.5)
  98. [2.8.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.8.6)
  99. [2.7.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.7.6)
  100. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.6.7)
  101. [2.5.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.5.6)
  102. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.4.12)
  103. [2.3.10 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-28_ ](https://git-scm.com/docs/git/2.3.10)
  104. [2.2.3 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-04_ ](https://git-scm.com/docs/git/2.2.3)
  105. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.1.4)
  106. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git/es#_nombre)NOMBRE
git - el estúpido rastreador de contenido
##  [](https://git-scm.com/docs/git/es#_sinopsis)SINOPSIS
```
_git_ [-v | --version] [-h | --help] [-C <ruta>] [-c <nombre>=<valor>]
    [--exec-path[=<ruta>]] [--html-path] [--man-path] [--info-path]
    [-p | --paginate| -P | --no-pager] [--no-replace-objects] [--no-lazy-fetch]
    [--no-optional-locks] [--no-advice] [--bare] [--git-dir=<ruta>]
    [--work-tree=<ruta>] [--namespace=<nombre>] [--config-env=<nombre>=<var-ambiente>]
    <comando> [<argumentos>]
```

##  [](https://git-scm.com/docs/git/es#_descripci%C3%B3n)DESCRIPCIÓN
Git es un sistema de control de revisiones distribuido, rápido y escalable con un conjunto de comandos inusualmente rico que permite tanto operaciones de alto nivel como acceso completo a componentes internos.
Ver [gittutorial[7]](https://git-scm.com/docs/gittutorial/es) para comenzar, luego ver [giteveryday[7]](https://git-scm.com/docs/giteveryday/es) para un útil conjunto de comandos mínimo. El [Manual de Usuario de Git](https://git-scm.com/docs/user-manual/es) tiene una introducción mas a fondo.
Después que domines los conceptos básicos, puedes regresar a ésta página para aprender qué comandos ofrece Git. Puedes aprender mas sobre comandos Git individuales con el comando "git help comando". La página del manual [gitcli[7]](https://git-scm.com/docs/gitcli/es) te da una vistazo de la sintáxis de comandos en la línea de comandos.
Una copia formateada e hipervinculada de la mas reciente documentación de Git puede verse en <https://git.github.io/htmldocs/git.html> o <https://git-scm.com/docs>.
##  [](https://git-scm.com/docs/git/es#_opciones)OPCIONES

[](https://git-scm.com/docs/git/es#git--v)-v


[](https://git-scm.com/docs/git/es#git---version)--version

Imprime la versión de la suite Git de la cual proviene el programa _git_.
Esta opción es internamente convertida a `git` `version` ... y acepta las mismas opciones que el comando [git-version[1]](https://git-scm.com/docs/git-version/es). Si también se da `--help` toma precedencia sobre `--version`.

[](https://git-scm.com/docs/git/es#git--h)-h


[](https://git-scm.com/docs/git/es#git---help)--help

Imprime la sinopsis y una lista de los comandos más usados comúnmente. Si se da la opción `--all` o `-a` entonces todos los comandos disponibles se imprimen. Si un comando Git es nombrado, esta opción traerá la página del manual para ese comando.
Hay otras opciones disponibles para controlar cómo se muestra la página del manual. Ver [git-help[1]](https://git-scm.com/docs/git-help/es) para mayor información, porque `git` `--help` ... es convertido internamente en `git` `help` ....

[](https://git-scm.com/docs/git/es#git--Cruta) [](https://git-scm.com/docs/git/es#git--Cltrutagt)-C <ruta>

Corre como si git hubiera iniciado en _< ruta>_ en lugar del directorio de trabajo actual. Cuando se dan múltiples opciones `-C`, cada `-C` _< ruta>_ no-absoluta subsecuente se interpreta como relativa al `-C` _< ruta>_ precedente. Si _< ruta>_ esta presente pero vacía, ej. `-C` `""`, entonces el directorio de trabajo actual queda sin modificaciones.
Esta opción afecta opciones que esperan una ruta (como `--git-dir` y `--work-tree`), en donde sus interpretaciones de los nombres de ruta se harían relativos al directorio de trabajo a causa de la opción `-C`. Por ejemplo, las invocaciones siguientes son equivalentes:
```
git --git-dir=a.git --work-tree=b -C c status
git --git-dir=c/a.git --work-tree=c/b status
```


[](https://git-scm.com/docs/git/es#git--cnombrevalor) [](https://git-scm.com/docs/git/es#git--cltnombregtltvalorgt)-c <nombre>=<valor>

Pasa un parámetro de configuración al comando. El valor dado sobreescribirá valores de ficheros de configuración. El <nombre> se espera en el mismo formato como se lista por _git config_ (subclaves separadas por puntos).
Nota que es permitido omitir el `=` en `git` `-c` `foo.bar` ... y se asignará a `foo.bar` el valor booleano true (así como [`foo`]`bar` lo haría en un fichero de configuración). Incluir el igual pero con un valor vacío (como `git` `-c` `foo.bar=` ...) asigna a `foo.bar` la cadena vacía que `git` `config` `--type=bool` convertirá a `false`.

[](https://git-scm.com/docs/git/es#git---config-envnombrevariable-de-ambiente) [](https://git-scm.com/docs/git/es#git---config-envltnombregtltvariable-de-ambientegt)--config-env=<nombre>=<variable-de-ambiente>

Como `-c` _< nombre>_`=`_< valor>_, da a la variable de configuración _< nombre>_ un valor, donde <variable-de-ambiente> es el nombre de una variable de ambiente de la cual se obtiene el valor. Al contrario que `-c` no hay un atajo para asignar directamente el valor a una cadena vacía, en cambio, a la variable de ambiente misma se le debe asignar la cadena vacía. Es un error si la _< variable-de-ambiente>_ no existe en el ambiente. _< variable-de-ambiente>_ no puede contener un signo de igual para evitar ambigüedad con _< nombre>_ que contenga.
Esto es útil en casos donde quieres pasar a git opciones de configuración transitorias, pero se hacen tan en el sistema oprativo donde otros procesos pueden ser capaces de leer tu línea de comandos (ej. `/proc/self/cmdline`), pero no tu ambiente (ej. `/proc/self/environ`). Ese es el comportamiento predeterminado en Linux, pero pudiera no serlo en tu sistema.
Nota que esto puede agregar seguridad para variables como `http.extraHeader` donde la información sensible es parte del valor, pero no ej. `url.`_< base>_`.insteadOf` donde la información sensible puede ser parte de la clave.

[](https://git-scm.com/docs/git/es#git---exec-pathruta) [](https://git-scm.com/docs/git/es#git---exec-pathltrutagt)--exec-path[=<ruta>]

Ruta a dondequiera que estén instalados tus programas del núcleo de Git. Esto también puede ser controlado asignando la variable de ambiente GIT_EXEC_PATH. Si no se proporciona ruta _git_ imprimirá la configuración actual y saldrá.

[](https://git-scm.com/docs/git/es#git---html-path)--html-path

Imprime la ruta, sin la última diagonal, donde esta instalada la documentación HTML de Git y sale.

[](https://git-scm.com/docs/git/es#git---man-path)--man-path

Imprime la ruta del manual (ver `man`(`1`)) para las páginas del manual de esta versión de Git y sale.

[](https://git-scm.com/docs/git/es#git---info-path)--info-path

Imprime la ruta donde están instalados los ficheros de información documentando esta versión de Git y sale.

[](https://git-scm.com/docs/git/es#git--p)-p


[](https://git-scm.com/docs/git/es#git---paginate)--paginate

Entuba toda la salida hacia _less_ (o si esta configurado, $PAGER) si la salida estándar es una terminal. Esto sobreescribe las opciones de configuración `pager.`_< comando>_ (ver la sección "Mecanismo de Configuración" mas abajo).

[](https://git-scm.com/docs/git/es#git--P)-P


[](https://git-scm.com/docs/git/es#git---no-pager)--no-pager

No entuba la salida de Git hacia el paginador.

[](https://git-scm.com/docs/git/es#git---git-dirruta) [](https://git-scm.com/docs/git/es#git---git-dirltrutagt)--git-dir=<ruta>

Asigna la ruta al repositorio (directorio ".git"). Esto también puede ser controlado configurando la variable de ambiente `GIT_DIR`. Puede ser una ruta absoluta o relativa al directorio de trabajo actual.
Especificando la ubicación del directorio ".git" usando esta opción (o la variable de ambiente `GIT_DIR`) apaga el descubrimiento de repositorio que intenta encontrar un directorio con subdirectorio ".git" (que es como se descubren el repositorio y el nivel mas alto del árbol de trabajo), y le dice a Git que estás en el nivel mas alto del árbol de trabajo. Si no estas en el directorio de nivel mas alto del árbol de trabajo, deberías decirle a Git dónde esta el nivel más alto del árbol de trabajo con la opción `--work-tree=`_< ruta>_ (o la variable de ambiente `GIT_WORK_TREE`)
Si sólo quieres correr git como si fuera arrancado en _< ruta>_ entonces usa `git` `-C` _< ruta>_.

[](https://git-scm.com/docs/git/es#git---work-treeruta) [](https://git-scm.com/docs/git/es#git---work-treeltrutagt)--work-tree=<ruta>

Asigna la ruta al árbol de trabajo. Puede ser una ruta absoluta o relativa al directorio de trabajo actual. Esto puede se controlado asignando la variable de ambiente GIT_WORK_TREE y la variable de configuración core.worktree (ver core.worktree en [git-config[1]](https://git-scm.com/docs/git-config/es) para una discusión mas detallada).

[](https://git-scm.com/docs/git/es#git---namespaceruta) [](https://git-scm.com/docs/git/es#git---namespaceltrutagt)--namespace=<ruta>

Asigna el espacio de nombres de Git. Ver [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/es) para mas detalles. Equivalente a asignar la variable de ambiente `GIT_NAMESPACE`.

[](https://git-scm.com/docs/git/es#git---bare)--bare

Trata el repositorio como un repositorio básico. Si la variable de ambiente GIT_DIR no esta asignada, se asigna al directorio de trabajo actual.

[](https://git-scm.com/docs/git/es#git---no-replace-objects)--no-replace-objects

No usa remplazamiento de referencias para remplazar objetos Git. Esto equivale a exportar la variable de ambiente `GIT_NO_REPLACE_OBJECTS` con cualquier valor. Ver [git-replace[1]](https://git-scm.com/docs/git-replace/es) para mas información.

[](https://git-scm.com/docs/git/es#git---no-lazy-fetch)--no-lazy-fetch

No trae objetos faltantes desde el remoto prometente bajo demanda. Útil junto con `git` `cat-file` `-e` _< objeto>_ para ver si el objeto esta localmente disponible. Esto es equivalente a asignar `1` a la variable de ambiente `GIT_NO_LAZY_FETCH`.

[](https://git-scm.com/docs/git/es#git---no-optional-locks)--no-optional-locks

No realiza operaciones opcionales que requieran bloqueos. Es equivalente a asignar `0` a `GIT_OPTIONAL_LOCKS`.

[](https://git-scm.com/docs/git/es#git---no-advice)--no-advice

Deshabilita la impresión de todas las sugerencias.

[](https://git-scm.com/docs/git/es#git---literal-pathspecs)--literal-pathspecs

Trata las especificaciones de ruta literalmente (ej. sin interpretar glob, sin especificaciones de ruta mágicas). Es equivalente a asignar la variable de ambiente `GIT_LITERAL_PATHSPECS` con `1`.

[](https://git-scm.com/docs/git/es#git---glob-pathspecs)--glob-pathspecs

Agrega magia "glob" a todas las especificaciones de ruta. Es equivalente a asignar `1` a la variable de ambiente `GIT_GLOB_PATHSPECS`. Se puede deshabilitar interpretación de glob en especificaciones de ruta individuales usando la especificación de ruta mágica ":(literal)"

[](https://git-scm.com/docs/git/es#git---noglob-pathspecs)--noglob-pathspecs

Agrega magia "literal" a todas las especificaciones de ruta. Es equivalente a asignar `1` a la variable de ambiente `GIT_NOGLOB_PATHSPECS`. Se puede habilitar interpretación de glob en especificaciones de ruta individuales usando la especificación de ruta mágica ":(glob)"

[](https://git-scm.com/docs/git/es#git---icase-pathspecs)--icase-pathspecs

Agrega magia "icase" a todas las especificaciones de ruta. Es equivalente a asignar `1` a la variable de ambiente `GIT_ICASE_PATHSPECS`.

[](https://git-scm.com/docs/git/es#git---list-cmdsgrupogrupo) [](https://git-scm.com/docs/git/es#git---list-cmdsltgrupogtltgrupogt82308203)--list-cmds=<grupo>[,<grupo>…​]

Lista comandos por grupo. Es una opción interna/experimental y puede cambiar o ser removida en el futuro. Los grupos soportados son: builtins, parseopt (comandos interconstruidos que usan opciones de parseo), deprecated (interconstruidos obsoletos), main (todos los comandos en el directorio libexec), others (todos los otros comandos en `$PATH` que tienen el prefijo git-), list-<categoría> (ver categorías en command-list.txt), nohelpers (excluye comandos auxiliares), alias y config (obtiene la lista de comandos de la variable de configuración completion.commands)

[](https://git-scm.com/docs/git/es#git---attr-sourcerbol-ismo) [](https://git-scm.com/docs/git/es#git---attr-sourceltrbol-ismogt)--attr-source=<árbol-ismo>

Lee atributos git de <árbol-ismo> en lugar del árbol de trabajo. Ver [gitattributes[5]](https://git-scm.com/docs/gitattributes/es). Equivale a asignar la variable de ambiente `GIT_ATTR_SOURCE`.
##  [](https://git-scm.com/docs/git/es#_comandos_git)COMANDOS GIT
Dividimos Git en comandos de alto nivel ("porcelana") y comandos de bajo nivel ("plomería").
##  [](https://git-scm.com/docs/git/es#_comandos_de_alto_nivel_porcelana)Comandos de alto nivel (porcelana)
Separamos los comandos porcelana en comandos principales y algunas utilidades de usuario auxiliares.
###  [](https://git-scm.com/docs/git/es#_comandos_porcelana_principales)Comandos porcelana principales
Warning |  Missing `es/{build_dir}/cmds-mainporcelain.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/es#_comandos_auxiliares)Comandos Auxiliares
Manipuladores:
Warning |  Missing `es/{build_dir}/cmds-ancillarymanipulators.adoc` See original version for this content.
---|---
Interrogadores:
Warning |  Missing `es/{build_dir}/cmds-ancillaryinterrogators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/es#_interactuando_con_otros)Interactuando con Otros
Estos comandos son para interactuar con otros SCM y con otra gente vía parche sobre correo electrónico.
Warning |  Missing `es/{build_dir}/cmds-foreignscminterface.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/es#_resetear_restaurar_y_revertir)Resetear, restaurar y revertir
Hay tres comandos con nombres similares: `git` `reset`, `git` `restore` y `git` `revert`.
  * [git-revert[1]](https://git-scm.com/docs/git-revert/es) es acerca de hacer un nuevo commit que revierta los cambios hechos por otros commits.
  * [git-restore[1]](https://git-scm.com/docs/git-restore/es) es acerca de restaurar ficheros en el árbol de trabajo de ya sea el índice u otro commit. Este comando no actualiza tu rama. El comando también puede usarse para restaurar ficheros en el índice de otro commit.
  * [git-reset[1]](https://git-scm.com/docs/git-reset/es) es acerca de actualizar tu rama, moviendo la punta con el fin de agregar o eliminar commits de la rama. Esta operación cambia el historial de commits.
`git` `reset` también puede usarse para restaurar el índice, traslapando con `git` `restore`.


##  [](https://git-scm.com/docs/git/es#_comandos_de_bajo_nivel_plomer%C3%ADa)Comandos de bajo nivel (plomería)
Aunque Git incluye su propia capa de porcelana, sus comandos de bajo nivel son suficientes para soportar desarrollo de porcelanas alternativas. Desarrolladores de tales porcelanas podrían comenzar leyendo acerca de [git-update-index[1]](https://git-scm.com/docs/git-update-index/es) y [git-read-tree[1]](https://git-scm.com/docs/git-read-tree/es).
La interfase (entrada, salida, conjunto de opciones y la semántica) a esos comandos de bajo nivel tienen la intención de ser mucho mas estables que comandos a nivel porcelana, porque esos comandos son primordialmente para ser usados por scripts. Por otro lado, la interface a comandos porcelana esta sujeta a cambios con el fin de mejorar la experiencia de usuario final.
La descripción siguiente divide los comandos de bajo nivel en comandos que manipulan objetos (en el repositorio, índice y árbol de trabajo), comandos que interrogan y comparan objetos, y comandos que mueven objetos y referencias entre repositorios.
###  [](https://git-scm.com/docs/git/es#_comandos_de_manipulaci%C3%B3n)Comandos de manipulación
Warning |  Missing `es/{build_dir}/cmds-plumbingmanipulators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/es#_comandos_de_interrogaci%C3%B3n)Comandos de interrogación
Warning |  Missing `es/{build_dir}/cmds-plumbinginterrogators.adoc` See original version for this content.
---|---
En general, los comandos de interrogación no tocan los ficheros en el árbol de trabajo.
###  [](https://git-scm.com/docs/git/es#_sincronizando_repositorios)Sincronizando repositorios
Warning |  Missing `es/{build_dir}/cmds-synchingrepositories.adoc` See original version for this content.
---|---
Los siguientes son comandos auxiliares usados por los anteriores; usuarios finales típicamente no los usan directamente.
Warning |  Missing `es/{build_dir}/cmds-synchelpers.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/es#_comandos_auxiliares_internos)Comandos auxiliares internos
Estos son comandos auxiliares internos usados por otros comandos; usuarios finales típicamente no los usan directamente.
Warning |  Missing `es/{build_dir}/cmds-purehelpers.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/es#_gu%C3%ADas)Guías
Las páginas de documentación siguientes son guías acerca de conceptos de Git.
Warning |  Missing `es/{build_dir}/cmds-guide.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/es#_interfases_de_repositorio_comando_y_fichero)Interfases de repositorio, comando y fichero
Esta documentación discute interfases de repositorio y comando con las cuales se espera que los usuarios interactúen directamente. Ver `--user-formats` en [git-help[1]](https://git-scm.com/docs/git-help/es) para mas detalles sobre los criterios.
Warning |  Missing `es/{build_dir}/cmds-userinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/es#_formatos_de_fichero_protocolos_y_otras_interfaces_para_el_desarrollador)Formatos de fichero, protocolos y otras interfaces para el desarrollador
Esta documentación discute los formatos de fichero, protocolos sobre-el-cable y otras interfases de desarrollador git. Ver `--developer-interfaces` en [git-help[1]](https://git-scm.com/docs/git-help/es).
Warning |  Missing `es/{build_dir}/cmds-developerinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/es#_mecanismo_de_configuraci%C3%B3n)Mecanismo de Configuración
Git usa un formato de texto simple para almacenar personalizaciones que son por repositorio y por usuario. Tal fichero de configuración puede parecerse a éste:
```
#
# Un caracter '#' o ';' indica un comentario.
#

; variables esenciales
[core]
	; No confiar modos de fichero
	filemode = false

; identidad del usuario
[user]
	name = "Junio C Hamano"
	email = "gitster@pobox.com"
```

Varios comandos leen del fichero de configuración y ajustan su operación respectivamente. Ver [git-config[1]](https://git-scm.com/docs/git-config/es) para una lista y mas detalles acerca del mecanismo de configuración.
##  [](https://git-scm.com/docs/git/es#_terminolog%C3%ADa_identificadora)Terminología Identificadora

[](https://git-scm.com/docs/git/es#git-objeto) [](https://git-scm.com/docs/git/es#git-ltobjetogt)<objeto>

Indica el nombre del objeto para cualquier tipo de objeto.

[](https://git-scm.com/docs/git/es#git-blob) [](https://git-scm.com/docs/git/es#git-ltblobgt)<blob>

Indica un nombre de objeto blob.

[](https://git-scm.com/docs/git/es#git-rbol) [](https://git-scm.com/docs/git/es#git-ltrbolgt)<árbol>

Indica un nombre de objeto árbol.

[](https://git-scm.com/docs/git/es#git-confirmacin) [](https://git-scm.com/docs/git/es#git-ltconfirmacingt)<confirmación>

Indica un nombre de objeto commit.

[](https://git-scm.com/docs/git/es#git-rbol-ismo) [](https://git-scm.com/docs/git/es#git-ltrbol-ismogt)<árbol-ismo>

Indica un nombre de objeto árbol, commit o etiqueta. Un comando que toma un argumento <arbol-ismo> quiere operar en última instancia sobre un objeto <árbol> pero automáticamente desreferencia objetos <commit> y <etiqueta> que apuntan a un <árbol>.

[](https://git-scm.com/docs/git/es#git-confirmacion-ismo) [](https://git-scm.com/docs/git/es#git-ltconfirmacion-ismogt)<confirmacion-ismo>

Indica un nombre de objeto commit o etiqueta. Un comando que toma un argumento <commit-ish> de último quiere operar sobre un objeto <commit> pero automáticamente desreferencia objetos <etiqueta> que apunten a un <commit>.

[](https://git-scm.com/docs/git/es#git-tipo) [](https://git-scm.com/docs/git/es#git-lttipogt)<tipo>

Indica que un tipo de objeto es requerido. Actualmente uno de: `blob`, `tree`, `commit`, o `tag`.

[](https://git-scm.com/docs/git/es#git-fichero) [](https://git-scm.com/docs/git/es#git-ltficherogt)<fichero>

Indica un nombre de fichero - casi siempre relativo a la raíz de la estructura del árbol que describe `GIT_INDEX_FILE`.
##  [](https://git-scm.com/docs/git/es#_identificadores_simb%C3%B3licos)Identificadores Simbólicos
Cualquier comando Git que acepte cualquier <objeto> también puede usar la notación simbólica siguiente:

[](https://git-scm.com/docs/git/es#git-CABEZA)CABEZA

indica la cabeza de la rama actual.

[](https://git-scm.com/docs/git/es#git-etiqueta) [](https://git-scm.com/docs/git/es#git-ltetiquetagt)<etiqueta>

un _nombre_ valido de etiqueta (ej. una referencia `refs/tags/`_< etiqueta>_).

[](https://git-scm.com/docs/git/es#git-cabeza) [](https://git-scm.com/docs/git/es#git-ltcabezagt)<cabeza>

un _nombre_ valido de cabeza (ej. una referencia `refs/heads/`_< cabeza>_).
Para una lista completa de las maneras de deletrear nombres de objetos ver la sección "ESPECIFICANDO REVISIONES" en [gitrevisions[7]](https://git-scm.com/docs/gitrevisions/es).
##  [](https://git-scm.com/docs/git/es#_estructura_de_ficherosdirectorios)Estructura de Ficheros/Directorios
Por favor ver el documento [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/es).
Leer [githooks[5]](https://git-scm.com/docs/githooks/es) para mas detalles sobre cada gancho.
Gestores de Código Fuente de alto nivel pueden proveer y manejar información adicional en el `$GIT_DIR`.
##  [](https://git-scm.com/docs/git/es#_terminolog%C3%ADa)Terminología
Favor de ver [gitglossary[7]](https://git-scm.com/docs/gitglossary/es).
##  [](https://git-scm.com/docs/git/es#_variables_de_ambiente)Variables de Ambiente
Varios comandos de Git prestan atención a variables de ambiente y alteran su funcionamiento. Las variables de ambiente marcadas como "Booleanas" toman sus valores de la misma manera que variables de configuración booleanas, ej. "true", "yes", "on" y números positivos se consideran como "yes", mientras "false", "no", "off" y "0" se toman como "no".
Aquí las variables:
###  [](https://git-scm.com/docs/git/es#_sistema)Sistema

[](https://git-scm.com/docs/git/es#git-HOME) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeHOMEcodespan)`HOME`

Specifies the path to the user’s home directory. On Windows, if unset, Git will set a process environment variable equal to: `$HOMEDRIVE$HOMEPATH` if both `$HOMEDRIVE` and `$HOMEPATH` exist; otherwise `$USERPROFILE` if `$USERPROFILE` exists.
###  [](https://git-scm.com/docs/git/es#_el_repositorio_git)El Repositorio Git
Esas variables de ambiente aplican a _todos_ los comandos de núcleo de Git. Nótese bien: cabe notar que pueden ser usadas/sobremontadas por Gestores de Código Fuente asentados sobre Git, entonces tener cuidado si se usa un front-end foráneo.

[](https://git-scm.com/docs/git/es#git-GITINDEXFILE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITINDEXFILEcodespan)`GIT_INDEX_FILE`

Esta variable de ambiente especifica un fichero de índice alterno. Si no se especifica, se usa el valor predeterminado en `$GIT_DIR/index`.

[](https://git-scm.com/docs/git/es#git-GITINDEXVERSION) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITINDEXVERSIONcodespan)`GIT_INDEX_VERSION`

Esta variable de ambiente especifica qué versión de índice se usa al escribir el fichero de índice. No afectará ficheros de índice existentes. De manera predeterminada se usa la versión 2 o 3 del fichero de índice. Ver [git-update-index[1]](https://git-scm.com/docs/git-update-index/es) para mas información.

[](https://git-scm.com/docs/git/es#git-GITOBJECTDIRECTORY) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITOBJECTDIRECTORYcodespan)`GIT_OBJECT_DIRECTORY`

Si el directorio de almacenamiento de objetos se especifica por medio de esta variable de ambiente, entonces los directorios sha1 se crean debajo - de lo contrario se usa el directorio predeterminado `$GIT_DIR/objects`.

[](https://git-scm.com/docs/git/es#git-GITALTERNATEOBJECTDIRECTORIES) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITALTERNATEOBJECTDIRECTORIEScodespan)`GIT_ALTERNATE_OBJECT_DIRECTORIES`

Debido a la naturaleza inmutable de los objetos Git, objetos antiguos pueden ser archivados en directorios compartidos de sólo lectura. Esta variable especifica una lista separada por ":" (en Windows separada por ";") de directorios de objetos Git que pueden ser usados para buscar objetos Git. Objetos nuevos no serán escritos en esos directorios.
Entradas que comienzan con `"` (comilla doble) serán interpretadas como rutas entrecomilladas estilo C, quitando la comillas dobles iniciales y finales y respetando escapes de diagonal invertida. Ej. el valor _"ruta-con-\"-y-:-en-ella":ruta-vainilla_ tiene dos rutas: `ruta-con-"-y-:-en-ella` y `ruta-vainilla`.

[](https://git-scm.com/docs/git/es#git-GITDIR) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITDIRcodespan)`GIT_DIR`

Si la variable de ambiente `GIT_DIR` esta asignada entonces especifica una ruta para usarse en lugar de la predeterminada `.git` para la base del repositorio. La opción de línea de comando `--git-dir` también asigna éste valor.

[](https://git-scm.com/docs/git/es#git-GITWORKTREE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITWORKTREEcodespan)`GIT_WORK_TREE`

Asigna la ruta de la raíz del árbol de trabajo. También puede controlarse con la opción de línea de comando `--work-tree` y la variable de configuración core.worktree.

[](https://git-scm.com/docs/git/es#git-GITNAMESPACE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITNAMESPACEcodespan)`GIT_NAMESPACE`

Asigna el espacio de nombres de Git; ver [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/es) para detalles. La opción de línea de comandos `--namespace` también asigna éste valor.

[](https://git-scm.com/docs/git/es#git-GITCEILINGDIRECTORIES) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCEILINGDIRECTORIEScodespan)`GIT_CEILING_DIRECTORIES`

Esta debe ser una lista separada por dos puntos de rutas absolutas. Si se asigna, es una lista de directorios en los que Git no debería hacer chdir al buscar un directorio de repositorio (útil para excluir directorios de red de carga lenta). No excluirá el directorio de trabajo actual o un GIT_DIR configurado en línea de comandos o en el ambiente. Normalmente, Git tiene que leer las entradas en esta lista y resolver cualquier enlace simbólico que pueda estar presente con el fin de compararlos con el directorio actual. Sin embargo, si incluso éste acceso es lento, puedes agregar a la lista una entrada vacía para indicarle a Git que las entradas subsecuentes no son enlaces simbólicos y que por lo tanto no necesitan resolverse; ej. `GIT_CEILING_DIRECTORIES=/posible/enlace::/no/enlace/muy/lento`.

[](https://git-scm.com/docs/git/es#git-GITDISCOVERYACROSSFILESYSTEM) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITDISCOVERYACROSSFILESYSTEMcodespan)`GIT_DISCOVERY_ACROSS_FILESYSTEM`

Cuando se ejecuta en un directorio que no tiene directorio de repositorio ".git", Git intenta encontrarlo en los directorios padres para encontrar el tope del directorio de trabajo, pero predeterminadamente no cruza los límites del sistema de ficheros. A esta variable de ambiente booleana se le puede asignar true para indicarle a Git que no pare en los límites del sistema operativo. Así como `GIT_CEILING_DIRECTORIES`, no afectará un directorio de repositorio explícito configurado en `GIT_DIR` o en la línea de comandos.

[](https://git-scm.com/docs/git/es#git-GITCOMMONDIR) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCOMMONDIRcodespan)`GIT_COMMON_DIR`

Si a esta variable se le asigna una ruta, los ficheros que no son del árbol de trabajo que normalmente están en $GIT_DIR serán tomados en cambio de esta ruta. Ficheros específicos del árbol de trabajo como HEAD y index se toman de $GIT_DIR. Ver [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/es) y [git-worktree[1]](https://git-scm.com/docs/git-worktree/es) para detalles. Esta variable tiene precedencia mas baja que otras variables de ruta como GIT_INDEX_FILE, GIT_OBJECT_DIRECTORY…​

[](https://git-scm.com/docs/git/es#git-GITDEFAULTHASH) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITDEFAULTHASHcodespan)`GIT_DEFAULT_HASH`

Si se configura esta variable, el algoritmo predeterminado de hash para repositorios nuevos será asignado con éste valor. Al clonar se ignora este valor y siempre se usa la configuración del repositorio remoto. El predeterminado es "sha1". Ver `--object-format` en [git-init[1]](https://git-scm.com/docs/git-init/es).

[](https://git-scm.com/docs/git/es#git-GITDEFAULTREFFORMAT) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITDEFAULTREFFORMATcodespan)`GIT_DEFAULT_REF_FORMAT`

Si se configura esta variable, el formato predeterminado de almacenamiento de referencias para repositorios nuevos será asignado con éste valor. El predeterminado es "files". Ver `--ref-format` en [git-init[1]](https://git-scm.com/docs/git-init/es).
###  [](https://git-scm.com/docs/git/es#_confirmaciones_de_git)Confirmaciones de Git

[](https://git-scm.com/docs/git/es#git-GITAUTHORNAME) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITAUTHORNAMEcodespan)`GIT_AUTHOR_NAME`

El nombre legible al humano usado en la identidad del autor cuando se crean objetos confirmación o etiqueta, o cuando se escriben reflogs. Anula las configuraciones `user.name` y `author.name`.

[](https://git-scm.com/docs/git/es#git-GITAUTHOREMAIL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITAUTHOREMAILcodespan)`GIT_AUTHOR_EMAIL`

La dirección de correo electrónico usada en la identidad del autor cuando se crean objetos confirmación o etiqueta, o cuando se escriben reflogs. Anula las configuraciones `user.email` y `author.email`.

[](https://git-scm.com/docs/git/es#git-GITAUTHORDATE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITAUTHORDATEcodespan)`GIT_AUTHOR_DATE`

La fecha usada para la identidad del autor cuando se crean objetos confirmación o etiqueta, o cuando se escriben reflogs. Ver [git-commit[1]](https://git-scm.com/docs/git-commit/es) para formatos válidos.

[](https://git-scm.com/docs/git/es#git-GITCOMMITTERNAME) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCOMMITTERNAMEcodespan)`GIT_COMMITTER_NAME`

El nombre legible al humano usado en la identidad del confirmante cuando se crean objetos confirmación o etiqueta, o cuando se escriben referencias de bitácora. Anula las configuraciones de `user.name` y `committer.name`.

[](https://git-scm.com/docs/git/es#git-GITCOMMITTEREMAIL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCOMMITTEREMAILcodespan)`GIT_COMMITTER_EMAIL`

La dirección de correo electrónico usada en la identidad del autor cuando se crean objetos confirmación o etiqueta, o cuando se escriben referencias de bitácora. Anula las configuraciones de `user.email` y `committer.email`.

[](https://git-scm.com/docs/git/es#git-GITCOMMITTERDATE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCOMMITTERDATEcodespan)`GIT_COMMITTER_DATE`

La fecha usada para la identidad del confirmante cuando se crean objetos confirmación o etiqueta, o cuando se escriben referencias de bitácora. Ver [git-commit[1]](https://git-scm.com/docs/git-commit/es) para formatos válidos.

[](https://git-scm.com/docs/git/es#git-EMAIL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeEMAILcodespan)`EMAIL`

La dirección de correo electrónico usada en las identidades de autor y confirmante si no se ha asignado alguna otra variable de ambiente o configuración relevante.
###  [](https://git-scm.com/docs/git/es#_diffs_de_git)Diffs de Git

[](https://git-scm.com/docs/git/es#git-GITDIFFOPTS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITDIFFOPTScodespan)`GIT_DIFF_OPTS`

La única configuración válida es "--unified=??" o "-u??" para asignar el número de líneas de contexto a mostrarse cuando se crea un diff unificado. Toma precedencia sobre cualquier valor de opción "-U" o "--unified" pasada en la línea de comandos del diff Git.

[](https://git-scm.com/docs/git/es#git-GITEXTERNALDIFF) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITEXTERNALDIFFcodespan)`GIT_EXTERNAL_DIFF`

Cuando se asigna la variable de ambiente `GIT_EXTERNAL_DIFF`, se llama al programa nombrado en ella para generar diffs, y Git no usa su maquinaria de diff interconstruida. Para una ruta que es agregada, removida, o modificada, se llama a `GIT_EXTERNAL_DIFF` con 7 parámetros:
```
ruta fichero-anterior hex-anterior modo-anterior fichero-nuevo hex-nuevo modo-nuevo
```

donde:

[](https://git-scm.com/docs/git/es#git-fichero-anteriornuevo) [](https://git-scm.com/docs/git/es#git-fichero-ltanteriornuevogt)fichero-<anterior|nuevo>

son los ficheros que GIT_EXTERNAL_DIFF puede usar para leer el contenido de <anterior|nuevo>,

[](https://git-scm.com/docs/git/es#git-hex-anteriornuevo) [](https://git-scm.com/docs/git/es#git-hex-ltanteriornuevogt)hex-<anterior|nuevo>

son los hash SHA1 de 40 dígitos hexadecimal,

[](https://git-scm.com/docs/git/es#git-modo-anteriornuevo) [](https://git-scm.com/docs/git/es#git-modo-ltanteriornuevogt)modo-<anterior|nuevo>

son la representación octal de los modos del fichero.
Los parámetros fichero pueden apuntar al fichero de trabajo del usuario (ej. `fichero-nuevo` en "git-diff-files"), `/dev/null`(ej. `fichero-anterior` cuando se agrega un fichero nuevo), o un fichero temporal (ej. `fichero-anterior` en el índice). `GIT_EXTERNAL_DIFF` no debería preocuparse por desenlazar el fichero temporal — es eliminado cuando `GIT_EXTERNAL_DIFF` sale.
Para una ruta no-fusionada, se llama a `GIT_EXTERNAL_DIFF` con 1 parámetro, <ruta>.
Para cada ruta se llama a `GIT_EXTERNAL_DIFF`, dos variables de ambiente se asignan, `GIT_DIFF_PATH_COUNTER` y `GIT_DIFF_PATH_TOTAL`.

[](https://git-scm.com/docs/git/es#git-GITEXTERNALDIFFTRUSTEXITCODE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITEXTERNALDIFFTRUSTEXITCODEcodespan)`GIT_EXTERNAL_DIFF_TRUST_EXIT_CODE`

Si a esta variable de ambiente booleana se le asigna true entonces se espera que el comando `GIT_EXTERNAL_DIFF` regrese un código de salida 0 si considera que los ficheros de entrada son iguales, o 1 si considera que son diferentes, como `diff`(`1`). Si se le asigna false, el cual es el predeterminado, entonces se espera que el comando regrese un código de salida 0 independientemente de la igualdad. Cualquier otro código de salida provoca a Git a reportar un error fatal.

[](https://git-scm.com/docs/git/es#git-GITDIFFPATHCOUNTER) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITDIFFPATHCOUNTERcodespan)`GIT_DIFF_PATH_COUNTER`

Un contador base 1 incrementado por uno por cada ruta.

[](https://git-scm.com/docs/git/es#git-GITDIFFPATHTOTAL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITDIFFPATHTOTALcodespan)`GIT_DIFF_PATH_TOTAL`

El número total de rutas.
###  [](https://git-scm.com/docs/git/es#_otras)otras

[](https://git-scm.com/docs/git/es#git-GITMERGEVERBOSITY) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITMERGEVERBOSITYcodespan)`GIT_MERGE_VERBOSITY`

Un número controlando la cantidad de salida mostrada por la estrategia de fusión recursiva. Anula merge.verbosity. Ver [git-merge[1]](https://git-scm.com/docs/git-merge/es)

[](https://git-scm.com/docs/git/es#git-GITPAGER) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITPAGERcodespan)`GIT_PAGER`

Esta variable de ambiente anula `$PAGER`. Si se le asigna una cadena vacía o el valor "cat", Git no lanzará un paginador. Ver también la opción `core.pager` en [git-config[1]](https://git-scm.com/docs/git-config/es).

[](https://git-scm.com/docs/git/es#git-GITPROGRESSDELAY) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITPROGRESSDELAYcodespan)`GIT_PROGRESS_DELAY`

Un número controlando cuántos segundos retardar antes de mostrar indicadores opcionales de progreso. Predeterminado a 1.

[](https://git-scm.com/docs/git/es#git-GITEDITOR) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITEDITORcodespan)`GIT_EDITOR`

Esta variable de ambiente anula `$EDITOR` y `$VISUAL`. Es usada por varios comandos Git cuando en modo interactivo se va a lanzar un editor. Ver también [git-var[1]](https://git-scm.com/docs/git-var/es) y la opción `core.editor` en [git-config[1]](https://git-scm.com/docs/git-config/es).

[](https://git-scm.com/docs/git/es#git-GITSEQUENCEEDITOR) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITSEQUENCEEDITORcodespan)`GIT_SEQUENCE_EDITOR`

Esta variable de ambiente anula el editor de Git configurado cuando se edita la lista de pendientes en un rebase interactivo. Ver también [git-rebase[1]](https://git-scm.com/docs/git-rebase/es) y la opción `sequence.editor` en [git-config[1]](https://git-scm.com/docs/git-config/es).

[](https://git-scm.com/docs/git/es#git-GITSSH) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITSSHcodespan)`GIT_SSH`


[](https://git-scm.com/docs/git/es#git-GITSSHCOMMAND) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITSSHCOMMANDcodespan)`GIT_SSH_COMMAND`

Si cualquiera de estas variables de ambiente se asigna entonces _git fetch_ y _git push_ usarán el comando especificado en lugar de _ssh_ cuando se necesite conectar a un sistema remoto. Los parámetros de línea de comandos pasados al comando configurado los determina la variante de ssh. Ver la opción `ssh.variant` en [git-config[1]](https://git-scm.com/docs/git-config/es) para detalles.
`$GIT_SSH_COMMAND` toma precedencia sobre `$GIT_SSH`, y es interpretado por el shell, el cual permite argumentos adicionales a incluirse. Por otro lado, `$GIT_SSH` debe ser sólo la ruta al programa (el cual puede ser un script de shell envolvente, si se necesitan argumentos adicionales).
Usualmente es mas fácil configurar cualquier opción deseada por medio de tu fichero personal `.ssh/config`. Por favor consulta tu documentación de ssh para mayores detalles.

[](https://git-scm.com/docs/git/es#git-GITSSHVARIANT) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITSSHVARIANTcodespan)`GIT_SSH_VARIANT`

Si se asigna ésta variable de ambiente, anula que Git autodetecte si `GIT_SSH`/`GIT_SSH_COMMAND`/`core.sshCommand` se refiere a OpenSSH, link o tortoiseplink. Esta variable anula la configuración `ssh.variant` que sirve para el mismo propósito.

[](https://git-scm.com/docs/git/es#git-GITSSLNOVERIFY) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITSSLNOVERIFYcodespan)`GIT_SSL_NO_VERIFY`

Asignando y exportando ésta variable de ambiente a cualquier valor le dice a Git que no verifique el certificado SSL cuando haga fetch o push sobre HTTPS.

[](https://git-scm.com/docs/git/es#git-GITATTRSOURCE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITATTRSOURCEcodespan)`GIT_ATTR_SOURCE`

Asigna el árbol-ismo de donde se leerán gitattributes.

[](https://git-scm.com/docs/git/es#git-GITASKPASS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITASKPASScodespan)`GIT_ASKPASS`

Si se asigna esta variable de ambiente, entonces los comandos Git que necesiten recibir contraseñas o frases de acceso (ej. para autenticación HTTP o IMAP) llamarán a éste programa con una línea de entrada apropiada como argumento de línea de comandos y leer la contraseña de su STDOUT. Ver también la opción `core.askPass` en [git-config[1]](https://git-scm.com/docs/git-config/es).

[](https://git-scm.com/docs/git/es#git-GITTERMINALPROMPT) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTERMINALPROMPTcodespan)`GIT_TERMINAL_PROMPT`

Si se asigna ésta variable de ambiente booleana, git no usará una línea de entrada en la terminal (ej. cuando se solicite una autenticación HTTP).

[](https://git-scm.com/docs/git/es#git-GITCONFIGGLOBAL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCONFIGGLOBALcodespan)`GIT_CONFIG_GLOBAL`


[](https://git-scm.com/docs/git/es#git-GITCONFIGSYSTEM) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCONFIGSYSTEMcodespan)`GIT_CONFIG_SYSTEM`

Toma la configuración de los ficheros dados en lugar de los ficheros de configuración global o a nivel sistema. Si `GIT_CONFIG_SYSTEM` es asignado, el fichero de configuración de sistema definido en tiempo de construcción (usualmente `/etc/gitconfig`) no será leído. En el mismo sentido, si `GIT_CONFIG_GLOBAL` es asignado, ninguno de `$HOME/.gitconfig` o `$XDG_CONFIG_HOME/git/config` será leído. Se le puede asignar `/dev/null` para saltar la lectura de ficheros de configuración del nivel respectivo.

[](https://git-scm.com/docs/git/es#git-GITCONFIGNOSYSTEM) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCONFIGNOSYSTEMcodespan)`GIT_CONFIG_NOSYSTEM`

Si saltar la lectura de ajustes del fichero de ámbito de sistema `$`(`prefix`)`/etc/gitconfig`. Esta variable de ambiente booleana puede ser usada junto con `$HOME` y `$XDG_CONFIG_HOME` para crear un ambiente predecible para un script quisquilloso, o puedes asignarle verdadero para evitar temporalmente usar un fichero defectuoso `/etc/gitconfig` mientras se espera a alguien con premisos suficientes para arreglarlo.

[](https://git-scm.com/docs/git/es#git-GITFLUSH) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITFLUSHcodespan)`GIT_FLUSH`

Si a esta variable de ambiente booleana se le asigna true, entonces comandos como _git-blame_ (en modo incremental), _git rev-list_ , _git log_ , _git check-attr_ y _git check-ignore_ forzarán un desalojo del flujo de salida después de que cada registro sea desalojado. Si a esta variable se le asigna false, la salida de esos comandos se hará usando búfer de E/S por completo. Si no se asigna esta variable de ambiente, Git elegirá desalojo por búfer u orientada a registro con base en si la salida estándar parece ser redirigida a un fichero o no.

[](https://git-scm.com/docs/git/es#git-GITTRACE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEcodespan)`GIT_TRACE`

Habilita mensajes de rastreo general, ej. expansión de alias, ejecución de comando interconstruido y ejecución de comando externo.
Si a esta variable se le asigna "1", "2" o "true" (comparación sensible a mayúsculas), mensajes de rastreo se imprimirán en stderr.
Si a esta variable se le asigna un valor entero mayor a 2 y menor a 10 (estrictamente) entonces Git interpretará éste valor como un descriptor de fichero abierto e intentará escribir mensajes de rastro en éste descriptor de fichero.
Alternativamente, si a la variable se le asigna un ruta absoluta (iniciando con un caracter _/_), Git interpretará esta como una ruta de fichero e intentará adicionar mensajes de rastreo en él.
Desasignando la variable, o asignándole vacío, "0" o "false" (sensible a mayúsculas) deshabilita mensajes de rastreo.

[](https://git-scm.com/docs/git/es#git-GITTRACEFSMONITOR) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEFSMONITORcodespan)`GIT_TRACE_FSMONITOR`

Habilita mensajes de rastreo para la extensión de monitoreo de sistema de ficheros. Ver `GIT_TRACE` para las opciones de salida de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACEPACKACCESS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEPACKACCESScodespan)`GIT_TRACE_PACK_ACCESS`

Habilita mensajes de rastreo para todos los accesos a cualquier paquete. Para cada acceso, se registra el nombre de fichero de paquete y un corrimiento. Esto puede ser de ayuda para diagnosticar algunos problemas de desempeño relacionados con paquetes. Ver `GIT_TRACE` para opciones de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACEPACKET) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEPACKETcodespan)`GIT_TRACE_PACKET`

Habilita mensajes de rastreo para todos los paquetes que vienen de o van hacia un programa dado. Esto puede ayudar con depuración de negociación de objetos u otros problemas de protocolo. El rastreo esta apagado en un paquete que comienza con "PACK" (pero ver `GIT_TRACE_PACKFILE` mas abajo). Ver `GIT_TRACE` para opciones de salida de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACEPACKFILE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEPACKFILEcodespan)`GIT_TRACE_PACKFILE`

Habilita el rastreo de fichero de paquete enviados o recibidos por un programa dado. Contrario a otras salidas de rastreo, este rastreo es verboso: sin encabezados, y sin entrecomillar datos binarios. Seguramente querrás dirigirla a un fichero (ej. `GIT_TRACE_PACKFILE=/tmp/mi.paquete`) mas que desplegarla en la terminal o mezclarla con otra salida de rastreo.
Note que esto esta actualmente implementado sólo para el lado del cliente de clonaciones y fetchs.

[](https://git-scm.com/docs/git/es#git-GITTRACEPERFORMANCE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEPERFORMANCEcodespan)`GIT_TRACE_PERFORMANCE`

Habilita mensajes de rastreo relacionados con desempeño, ej. tiempo total de ejecución de cada comando Git. Ver `GIT_TRACE` para opciones de salida de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACEREFS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEREFScodespan)`GIT_TRACE_REFS`

Habilita mensajes de rastreo para operaciones en la base de datos de referencias. Ver `GIT_TRACE` para opciones de salida de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACESETUP) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACESETUPcodespan)`GIT_TRACE_SETUP`

Habilita mensajes de rastreo imprimiendo el .git, el árbol de trabajo y el directorio de trabajo actual después que Git haya terminado su fase de configuración. Ver `GIT_TRACE` para opciones de salida de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACESHALLOW) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACESHALLOWcodespan)`GIT_TRACE_SHALLOW`

Habilita mensajes de rastreo que pueden ayudar a depurar fetch / clonación de repositorios superficiales. Ver `GIT_TRACE` para opciones de salida de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACECURL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACECURLcodespan)`GIT_TRACE_CURL`

Habilita un volcado de rastreo completo de curl de todos los datos entrantes y salientes, incluyendo información descriptiva, del protocolo de transporte git. Es similar a hacer curl con `--trace-ascii` desde la línea de comandos. Ver `GIT_TRACE` para opciones de salida de rastreo disponibles.

[](https://git-scm.com/docs/git/es#git-GITTRACECURLNODATA) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACECURLNODATAcodespan)`GIT_TRACE_CURL_NO_DATA`

Cuando se habilita un rastreo curl (ver `GIT_TRACE_CURL` arriba), no vuelca los datos (esto es, sólo vuelca líneas de información y cabeceras).

[](https://git-scm.com/docs/git/es#git-GITTRACE2) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACE2codespan)`GIT_TRACE2`

Habilita mensajes de rastreo mas detallados desde la librería "trace2". La salida de `GIT_TRACE2` es un formato simple basado en texto para legibilidad humana.
Si a esta variable se le asigna "1", "2" o "true" (comparación sensible a mayúsculas), mensajes de rastreo se imprimirán en stderr.
Si a esta variable se le asigna un valor entero mayor a 2 y menor a 10 (estrictamente) entonces Git interpretará éste valor como un descriptor de fichero abierto e intentará escribir mensajes de rastro en éste descriptor de fichero.
Alternativamente, si a la variable se le asigna una ruta absoluta (que comience con el caracter _/_), Git la interpretará como una ruta de fichero e intentará añadir mensajes de rastreo en él. Si la ruta ya existe y es un directorio, los mensajes de rastreo serán escritos en ficheros (uno por proceso) en ese directorio, nombrados de acuerdo al último componente del SID y un contador opcional (para evitar colisiones de nombre de fichero).
Además, si a la variable se le asigna `af_unix:`[_< tipo-de-socket>_`:`]_< nombre-de-ruta-absoluta>_, Git intentará abrir la ruta como un Socket de Dominio de Unix. El tipo de socket puede ser `stream` o `dgram`.
Desasignando la variable, o asignándole vacío, "0" o "false" (sensible a mayúsculas) deshabilita mensajes de rastreo.
Ver [documentación de Trace2](https://git-scm.com/docs/api-trace2/es) para detalles completos.

[](https://git-scm.com/docs/git/es#git-GITTRACE2EVENT) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACE2EVENTcodespan)`GIT_TRACE2_EVENT`

Este ajuste escribe un formato basado en JSON que es adecuado para interpretación por máquina. Ver `GIT_TRACE2` para opciones disponibles de salida de rastreo y [documentación de Trace2](https://git-scm.com/docs/api-trace2/es) para detalles completos.

[](https://git-scm.com/docs/git/es#git-GITTRACE2PERF) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACE2PERFcodespan)`GIT_TRACE2_PERF`

Además de los mensajes basados en texto disponibles en `GIT_TRACE2`, este ajuste escribe un formato basado en columnas para entender regiones anidadas. Ver `GIT_TRACE` para opciones de salida de rastreo disponibles y [documentación de Trace2](https://git-scm.com/docs/api-trace2/es) para detalles completos.

[](https://git-scm.com/docs/git/es#git-GITTRACEREDACT) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITTRACEREDACTcodespan)`GIT_TRACE_REDACT`

Predeterminadamente, cuando se activa rastreo, Git redacta los valores de cookies, el encabezado "Authorization", el encabezado "Proxy-Authorization:" y fichero empaquetado de URIs. Asigne false a esta variable de ambiente booleana para prevenir esta redacción.

[](https://git-scm.com/docs/git/es#git-GITNOREPLACEOBJECTS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITNOREPLACEOBJECTScodespan)`GIT_NO_REPLACE_OBJECTS`

Asignando y exportando ésta variable de ambiente le dice a Git que ignore referencias de reemplazo y que no reemplace objetos Git.

[](https://git-scm.com/docs/git/es#git-GITLITERALPATHSPECS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITLITERALPATHSPECScodespan)`GIT_LITERAL_PATHSPECS`

Asignando verdadero a esta variable de ambiente booleana causará que Git trate a todas las especificaciones de ruta literalmente, mas que como patrones glob. Por ejemplo, corriendo `GIT_LITERAL_PATHSPECS=1` `git` `log` `--` `*.c'` buscará confirmaciones que toquen la ruta `*.c`, no cualquier ruta que coincida con el glob `*.c`. Querrías esto si proporcionas rutas literales a Git (ej., rutas que te hayan resultado previamente de `git` `ls-tree`, `--raw` salida de diff, etc.).

[](https://git-scm.com/docs/git/es#git-GITGLOBPATHSPECS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITGLOBPATHSPECScodespan)`GIT_GLOB_PATHSPECS`

Asignando verdadero a esta variable de ambiente booleana causará que Git trate todas las especificaciones de ruta como patrones glob (también conocido como magia "glob").

[](https://git-scm.com/docs/git/es#git-GITNOGLOBPATHSPECS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITNOGLOBPATHSPECScodespan)`GIT_NOGLOB_PATHSPECS`

Asignando verdadero a esta variable de ambiente booleana causará que Git trate a todas la especificaciones de ruta como literales (también conocido como magia "literal").

[](https://git-scm.com/docs/git/es#git-GITICASEPATHSPECS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITICASEPATHSPECScodespan)`GIT_ICASE_PATHSPECS`

Asignando verdadero a esta variable de ambiente booleana causará que Git trate a todas las especificaciones de ruta como insensibles a mayúsculas.

[](https://git-scm.com/docs/git/es#git-GITNOLAZYFETCH) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITNOLAZYFETCHcodespan)`GIT_NO_LAZY_FETCH`

Asignando verdadero a esta variable de ambiente booleana le dice a Git que no traiga perezosamente objetos faltantes del remoto promitente bajo demanda.

[](https://git-scm.com/docs/git/es#git-GITREFLOGACTION) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITREFLOGACTIONcodespan)`GIT_REFLOG_ACTION`

Cuando se actualiza una referencia, se crean entradas de reflog para dar seguimiento a la razón por la cual la referencia fue actualizada (la cual es típicamente el nombre de un comando de alto nivel que actualizó la referencia), además de los valores anterior y nuevo de la referencia. Un comando porcelana en un script puede usar la función auxiliar set_reflog_action en `git-sh-setup` para asignar su nombre a esta variable cuando es invocada por el usuario final como el comando de máximo nivel, para ser registrado en el cuerpo del reflog.

[](https://git-scm.com/docs/git/es#git-GITREFPARANOIA) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITREFPARANOIAcodespan)`GIT_REF_PARANOIA`

Si se asigna falso a esta variable de ambiente booleana, ignora referencias rotas o mal nombradas cuando se itera por la lista de referencias. Normalmente Git intentará incluir cualquiera de tales referencias, lo cual puede provocar que algunas operaciones fallen. Esto es usualmente preferible, ya que es mejor abortar operaciones potencialmente destructivas (ej. [git-prune[1]](https://git-scm.com/docs/git-prune/es)) en vez de ignorar referencias rotas (y por lo tanto considerar que no vale guardar el historial al que apuntan). El valor predeterminado es `1` (ej. ser paranoico en la detección y abortar todas las operaciones). Normalmente no deberías asignarle `0`, pero puede ser útil cuando se intenta salvar datos de un repositorio corrupto.

[](https://git-scm.com/docs/git/es#git-GITCOMMITGRAPHPARANOIA) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITCOMMITGRAPHPARANOIAcodespan)`GIT_COMMIT_GRAPH_PARANOIA`

Cuando se carga un objeto confirmación desde el grafo de confirmaciones, Git hace una revisión de existencia en el objeto en la base de datos de objetos. Esto se hace para evitar problemas con grafos de confirmación viciados que contengan referencias a confirmaciones ya eliminadas, pero viene con una penalización de desempeño.
El predeterminado es "false", el cual deshabilita el comportamiento antes mencionado. Asignar "true" habilita la revisión de existencia de tal manera que nunca se regresaran confirmaciones viciadas del grafo de confirmaciones con el costo de desempeño.

[](https://git-scm.com/docs/git/es#git-GITALLOWPROTOCOL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITALLOWPROTOCOLcodespan)`GIT_ALLOW_PROTOCOL`

Si se le asigna una lista de protocolos separada por dos puntos, se comporta como si a `protocolo.allow` se le asigna `never`, y cada uno de los protocolos listados `protocol.`_< nombre>_`.allow` tuviera asignado `always` (anulando cualquier configuración existente). Ver la descripción de `protocol.allow` en [git-config[1]](https://git-scm.com/docs/git-config/es) para mas detalles.

[](https://git-scm.com/docs/git/es#git-GITPROTOCOLFROMUSER) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITPROTOCOLFROMUSERcodespan)`GIT_PROTOCOL_FROM_USER`

Asigne falso a esta variable de ambiente booleana para prevenir el uso de protocolos por fetch/push/clone los cuales están configurados en el estado `user`. Esto es útil para restringir inicialización recursiva de submodulos desde un repositorio no confiable o para programas que alimenten URLs potencialmente no confiables a comandos git. Ver [git-config[1]](https://git-scm.com/docs/git-config/es) para mas detalles.

[](https://git-scm.com/docs/git/es#git-GITPROTOCOL) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITPROTOCOLcodespan)`GIT_PROTOCOL`

Sólo para uso interno. Usado en el protocolo de estrechamiento de manos de conexión. Contiene una lista de claves separadas por dos puntos _:_ con valores opcionales _< clave>[=<valor>]_. La presencia de claves y valores desconocidos debe ser ignorada.
Note que servidores pueden necesitar ser configurados para permitir que esta variable sobrepase algunos transportes. Será propagada automáticamente cuando se accesen repositorios locales (ej. `file://` o una ruta del sistema de ficheros), así como sobre el protocolo `git://`. Para git-over-http, debería funcionar automáticamente en la mayoría de las configuraciones, pero ver la discusión en [git-http-backend[1]](https://git-scm.com/docs/git-http-backend/es). Para git-over-ssh, el servidor ssh puede necesitar ser configurado para permitir a los clientes pasar esta variable (ej. usando `AcceptEnv` `GIT_PROTOCOL` con OpenSSH).
Esta configuración es opcional. Si la variable no es propagada, entonces los clientes caerán de vuelta a protocolo "v0" original (pero pueden perder algunas mejoras de desempeño o características). Esta variable afecta actualmente únicamente a clonados y fetchs; aún no es usada para empujes (pero podría serlo en el futuro).

[](https://git-scm.com/docs/git/es#git-GITOPTIONALLOCKS) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITOPTIONALLOCKScodespan)`GIT_OPTIONAL_LOCKS`

Si se le asigna falso a esta variable de ambiente, Git completará cualquier petición solicitada sin hacer cualquier sub-operación opcional que requiera un bloqueo. Por ejemplo, prevendrá que `git` `status` refresque el índice como efecto colateral. Esto es útil para procesos corriendo en segundo plano que no quieran provocar contención de bloqueos con otras operaciones en el repositorio. Es predeterminada a `1`.

[](https://git-scm.com/docs/git/es#git-GITREDIRECTSTDIN) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITREDIRECTSTDINcodespan)`GIT_REDIRECT_STDIN`


[](https://git-scm.com/docs/git/es#git-GITREDIRECTSTDOUT) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITREDIRECTSTDOUTcodespan)`GIT_REDIRECT_STDOUT`


[](https://git-scm.com/docs/git/es#git-GITREDIRECTSTDERR) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITREDIRECTSTDERRcodespan)`GIT_REDIRECT_STDERR`

Sólo Windows: permite redirigir la entrada/salida/error estándar a las rutas especificadas por la variables de ambiente. Esto es particularmente útil en aplicaciones multi-hilo donde no es opción la forma canónica para pasar manejadores estándar mediante `CreateProcess`() ya que requeriría que los manejadores sean marcados como heredables (y consecuentemente **todos** los procesos derivados los heredarán, posiblemente bloqueando operaciones regulares de Git). El caso de uso primordial es usar pipes nombradas para comunicación (ej. _\\\\.\pipe\mi-stdin-git-123_).
Dos valores especiales son soportados: `off` simplemente cerrará el manejador estándar correspondiente, y si `GIT_REDIRECT_STDERR` es _2 >&1_, error estándar será redireccionado al mismo manejador que la salida estándar.

[](https://git-scm.com/docs/git/es#git-GITPRINTSHA1ELLIPSISobsoleto) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITPRINTSHA1ELLIPSIScodespanobsoleto)`GIT_PRINT_SHA1_ELLIPSIS` (obsoleto)

Si se le asigna `yes`, imprime una elipsis después de una valor (abreviado) SHA-1. Esto afecta indicaciones de HEADs separadas ([git-checkout[1]](https://git-scm.com/docs/git-checkout/es)) y la salida bruta de diff ([git-diff[1]](https://git-scm.com/docs/git-diff/es)). Ya no se considera adecuado imprimir una elipsis en los casos mencionados y es probable que su soporte sea removido en el futuro previsible (junto con la variable).

[](https://git-scm.com/docs/git/es#git-GITADVICE) [](https://git-scm.com/docs/git/es#git-spanclasssynopsiscodeGITADVICEcodespan)`GIT_ADVICE`

If set to `0`, then disable all advice messages. These messages are intended to provide hints to human users that may help them get out of problematic situations or take advantage of new features. Users can disable individual messages using the `advice.*` config keys. These messages may be disruptive to tools that execute Git processes, so this variable is available to disable the messages. (The `--no-advice` global option is also available, but old Git versions may fail when this option is not understood. The environment variable will be ignored by Git versions that do not understand it.)
##  [](https://git-scm.com/docs/git/es#_discusi%C3%B3n)Discusión
Mas detalle de lo siguiente esta disponible en el [capítulo de Conceptos de Git del Manual de usuario](https://git-scm.com/docs/user-manual/es#git-concepts) y [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/es).
Un proyecto Git consiste normalmente de un directorio de trabajo con un subdirectorio ".git" en su nivel mas alto. El directorio .git contiene, entre otras cosas, una base de datos de objetos comprimida representando el historial completo del proyecto, un fichero "índice" el cual enlaza ese historial con el contenido actual del directorio de trabajo, y apuntadores nombrados hacia ese historial como etiquetas y cabezas de rama.
La base de datos de objetos contiene objetos de tres tipos principales: blobs, que contienen datos de fichero; árboles, los cuales apuntan a blobs y otros árboles para formar jerarquías de directorio; y confirmaciones, las que -cada una- referencían a un solo árbol y algún número de confirmaciones padre.
La confirmación, equivalente a lo que otros sistemas llaman "conjunto de cambios" o "versión", representa un paso en el historial del proyecto, y cada padre representa un paso inmediato anterior. Confirmaciones con mas de un padre representan fusiones de líneas independientes de desarrollo.
Todos los objetos se nombran con un hash SHA-1 de su contenido, normalmente escrito como una cadena de 40 dígitos hexadecimales. Dichos nombres son globalmente únicos. El historial completo hasta una confirmación puede ser garantizada firmando sólo esa confirmación. Para éste propósito, se proporciona un cuarto tipo de objeto, la etiqueta.
Recién creados, los objetos se almacenan en ficheros individuales, pero por eficiencia, posteriormente pueden ser comprimidos en conjunto en "paquetes de ficheros".
Apuntadores nombrados llamados referencias marcan puntos interesantes en el historial. Una referencia puede contener el nombre SHA-1 de un objeto o el nombre de otra referencia (ésta última se le llama una "referencia simbólica"). Referencias con nombres que comienzan con `refs/head/` contienen el nombre SHA-1 de la confirmación más reciente (o "head") de una rama bajo desarrollo. Los nombres SHA-1 de etiquetas de interés se almacenan bajo `refs/tags/`. Una referencia simbólica llamada `HEAD` contiene el nombre de la rama actualmente en revisión.
El fichero índice se inicializa con una lista de todas las rutas y, para cada ruta, un objeto blob y un conjunto de atributos. El objeto blob representa el contenido del fichero como en la cabeza de la rama actual. Los atributos (última hora de modificación, tamaño, etc.) se toman del fichero correspondiente en el árbol de trabajo. Cambios subsecuentes al árbol de trabajo se pueden encontrar al comparar esos atributos. El índice puede ser actualizado con contenido nuevo, y nuevas confirmaciones pueden ser creadas a partir del contenido almacenado en el índice.
El índice también es capaz de almacenar entradas múltiples (llamadas "etapas") para cada nombre de ruta dado. Esas etapas se usan para mantener las varias versiones sin fusionar de un fichero cuando una fusión está en progreso.
##  [](https://git-scm.com/docs/git/es#_seguridad)SEGURIDAD
Algunas opciones de configuración y ficheros gancho pueden causar que Git corra arbitrariamente comandos de terminal. Ya que configuraciones y ganchos no se copian usando `git` `clone`, es generalmente seguro clonar repositorios remotos con contenido no-confiable, inspeccionarlos con `git` `log`, y así sucesivamente.
Sin embrago, no es seguro correr comandos Git en un directorio `.git` (o el árbol de trabajo que lo rodea) cuando ese directorio `.git` mismo viene de un origen no confiable. Los comandos en su configuración y ganchos se ejecutan como de costumbre.
Predeterminadamente, Git se negará a correr cuando el repositorio pertenezca a otro usuario al que corra el comando. Ver la entrada para `safe.directory` en [git-config[1]](https://git-scm.com/docs/git-config/es). Mientras esto puede ayudar a protegerte en un ambiente multiusuario, nota que también puedes obtener repositorios no confiables que te pertenezcan (por ejemplo, si descomprimes un fichero zip o tarball de una fuente no confiable). En tales casos, necesitarás primero "sanitizar" el repositorio no confiable.
Si tienes un directorio `.git` no confiable, deberías primero clonarlo con `git` `clone` `--no-local` para obtener una copia limpia. Git restringe el conjunto de opciones y ganchos que correrán por `upload-pack`, el cual maneja el lado del servidor de un clone o fetch, pero ten cuidado que la superficie de ataque contra `upload-pack` es muy grande, así que esto conlleva algún riesgo. Lo mas seguro es servir el repositorio como un usuario sin privilegios (ya sea por [git-daemon[1]](https://git-scm.com/docs/git-daemon/es), ssh, o usando otras herramientas para cambiar identificadores de usuario). Ver la discusión en la sección `SEGURIDAD` de [git-upload-pack[1]](https://git-scm.com/docs/git-upload-pack/es).
##  [](https://git-scm.com/docs/git/es#_mas_documentaci%C3%B3n)MAS DOCUMENTACIÓN
Ver las referencias en la sección "descripción" para comenzar a usar Git. Lo siguiente es probablemente mas detalle del necesario para un usuario primerizo.
[El capítulo de conceptos de Git del manual de usuario](https://git-scm.com/docs/user-manual/es#git-concepts) y [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/es) ambos dan introducciones a la arquitectura subyacente de Git.
Ver [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/es) para un vistazo a los flujos de trabajo recomendados.
Ver también los documentos [Cómo hacer](https://git-scm.com/docs/howto-index/es) para algunos ejemplos útiles.
Lo interno se documenta en la [Documentación de la API de Git](https://git-scm.com/docs/api-index/es).
Usuarios migrando de CVS querrían leer [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/es).
##  [](https://git-scm.com/docs/git/es#_autores)Autores
Git lo comenzó Linus Torvalds, y actualmente es mantenido por Junio C Hamano. Numerosas contribuciones han venido de la lista de correos de Git <git@vger.kernel.org>. <http://openhub.net/p/git/contributors/summary> tiene una lista mas completa de contribuyentes.
Si tienes un clon mismo de git.git, la salida de [git-shortlog[1]](https://git-scm.com/docs/git-shortlog/es) y [git-blame[1]](https://git-scm.com/docs/git-blame/es) puede mostrarte los autores de partes específicas del proyecto.
##  [](https://git-scm.com/docs/git/es#_reportando_errores)Reportando Errores
Reporta errores en la lista de correo de Git <git@vger.kernel.org> donde se hace principalmente el desarrollo y mantenimiento. No tienes que estar suscrito en la lista para enviar un mensaje ahí. Ver el archivo de la lista en <https://lore.kernel.org/git> para reportes de error anteriores y otras discusiones.
Asuntos relevantes para la seguridad deben ser revelados en privado a la lista de correos de seguridad de Git <git-security@googlegroups.com>.
##  [](https://git-scm.com/docs/git/es#_ver_tambi%C3%A9n)VER TAMBIÉN
[gittutorial[7]](https://git-scm.com/docs/gittutorial/es), [gittutorial-2[7]](https://git-scm.com/docs/gittutorial-2/es), [giteveryday[7]](https://git-scm.com/docs/giteveryday/es), [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/es), [gitglossary[7]](https://git-scm.com/docs/gitglossary/es), [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/es), [gitcli[7]](https://git-scm.com/docs/gitcli/es), [El Manual de Usuario de Git](https://git-scm.com/docs/user-manual/es), [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/es)
##  [](https://git-scm.com/docs/git/es#_git)GIT
Parte de la suite de [git[1]](https://git-scm.com/docs/git/es)
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
